transport: Change the default port from 9695 to 6363.
diff --git a/ndn-cpp/transport/tcp-transport.hpp b/ndn-cpp/transport/tcp-transport.hpp
index 594f007..e6c2a73 100644
--- a/ndn-cpp/transport/tcp-transport.hpp
+++ b/ndn-cpp/transport/tcp-transport.hpp
@@ -24,9 +24,9 @@
     /**
      * Create a ConnectionInfo with the given host and port.
      * @param host The host for the connection.
      * @param port The port number for the connection. If omitted, use 9695.
      */
-    ConnectionInfo(const char *host, unsigned short port = 9695)
+    ConnectionInfo(const char *host, unsigned short port = 6363)
     : host_(host), port_(port)
     {
     }
@@ -24,9 +24,9 @@
      * Create a ConnectionInfo with the given host and port.
      * @param host The host for the connection.
-     * @param port The port number for the connection. If omitted, use 9695.
+     * @param port The port number for the connection. If omitted, use 6363.
      */
diff --git a/ndn-cpp/transport/udp-transport.hpp b/ndn-cpp/transport/udp-transport.hpp
index 633b9ad..a7a40b1 100644
--- a/ndn-cpp/transport/udp-transport.hpp
+++ b/ndn-cpp/transport/udp-transport.hpp
@@ -24,9 +24,9 @@
     /**
      * Create a ConnectionInfo with the given host and port.
      * @param host The host for the connection.
      * @param port The port number for the connection. If omitted, use 9695.
      */
-    ConnectionInfo(const char *host, unsigned short port = 9695)
+    ConnectionInfo(const char *host, unsigned short port = 6363)
     : host_(host), port_(port)
     {
     }
@@ -24,9 +24,9 @@
      * Create a ConnectionInfo with the given host and port.
      * @param host The host for the connection.
-     * @param port The port number for the connection. If omitted, use 9695.
+     * @param port The port number for the connection. If omitted, use 6363.
      */